@@ -1,4 +1,4 @@
-import pyautogui, re, time, os, shutil, keyboard, click, threading, pyperclip, easygui # type: ignore
+import pyautogui, re, time, os, shutil, keyboard, click, threading, pyperclip # type: ignore
 from datetime import datetime
 from os.path import exists
 from datetime import datetime
@@ -7,9 +7,15 @@ from pynput import keyboard as kbd # type: ignore
 
 kb = Controller()
 
+if os.name == 'nt':
+    import tkinter.messagebox as tkmb
+else:
+    import easygui
+
+
 #-----------------------------------------------------
 #
-# Clickomat v1.0.3
+# Clickomat v1.0.4
 #
 #-----------------------------------------------------
 
@@ -720,9 +726,14 @@ class Clickomat:
     # endregion
     # region _popupMessage(message,t='info') t -> type
     def _popupMessage(self,message,typ='info',title='Clickomat'):
-       if typ == "info": easygui.msgbox(title,message)
-       if typ == "error": easygui.msgbox(title,message)
-       if typ == "warning": easygui.msgbox(title,message)
+        if os.name == 'nt':
+            if typ == "info":    tkmb.showinfo(title=title, message=message)
+            if typ == "error":   tkmb.showerror(title=title, message=message)
+            if typ == "warning": tkmb.showwarning(title=title, message=message)
+        else:
+            if typ == "info": easygui.msgbox(message,title)
+            if typ == "error": easygui.msgbox(message,title)
+            if typ == "warning": easygui.msgbox(message,title)
     # endregion
     # region _screenshot()
     def _screenshot(self):
@@ -961,7 +972,7 @@ def run(version,path,clicklist,images,confidence,autoswitch,silent,step,noswitch
     if position: clipPositionLoop()
 
     if version:
-        print("Clickomat 1.0.3 is installed.\nYou may want to check if your version is up to date: pip list --outdated")
+        print("Clickomat 1.0.4 is installed.\nYou may want to check if your version is up to date: pip list --outdated")
         exit()
 
     case_path = path
